package com.capitalware.ufm.action.objects;

import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the If action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class ElseObject extends UFMObject
{
   public int                 exitRC = 0;
   public ArrayList<UFMObject> actionAL = null;
   
   /**
    * The constructor
    */
   public ElseObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (exitRC < 0)
         throw new IllegalArgumentException("Error: The exitrc attribute must be greater than 0.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     exitrc               = " + exitRC);
      
      if (actionAL != null)
      {
         UFM.logger.info("     Else Action Names:");
         for (int i=0; i < actionAL.size(); i++)
         {
            UFMObject fmo = actionAL.get(i);
            UFM.logger.info("       Action             = " + fmo.actionName);
         }
      }
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      al.add("<"+CWConstants.ELSE_ELEMENT+" "+CWConstants.EXIT_RC_ATTRIBUTE+"=\""+exitRC+"\">"+LINE_SEPARATOR);

      /*
       * Add info from actions
       */
      if (actionAL != null)
      {
         for (int i=0; i < actionAL.size(); i++)
         {
            UFMObject fmo = (UFMObject)actionAL.get(i);
            ArrayList<String> actionAL = fmo.toStringArray();
            for (int j=0; j < actionAL.size(); j++)
            {
               al.add("  "+actionAL.get(j));
            }
         }
      }
      
      al.add("</"+CWConstants.ELSE_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }
   
   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      s = CWConstants.ELSE_ELEMENT+", "+labelName+", "+CWConstants.ELSE_ELEMENT+", "+CWConstants.EXIT_RC_ATTRIBUTE+"="+exitRC+LINE_SEPARATOR;

      return s;
   }
}
