package com.capitalware.ufm.action.objects;

import java.io.File;
import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the HttpPutFile action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class HttpPutFileObject extends UFMFileObject
{
   public String     url = null;
   public String     srcFilename = null;
   public String     formDataName = "upload";

   /**
    * The constructor
    */
   public HttpPutFileObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (url != null)
         url   = Tokens.replace(url, paClass.actionProperties);
      if (srcFilename != null)
         srcFilename = Tokens.replace(srcFilename, paClass.actionProperties);
      if (formDataName != null)
         formDataName  = Tokens.replace(formDataName, paClass.actionProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (url == null)
         throw new IllegalArgumentException("Error: You must specify a URL for the HttpPutFile action.");

      if (srcFilename == null)
         throw new IllegalArgumentException("Error: You must specify a Source File for the HttpPutFile action.");

      if (formDataName == null)
         throw new IllegalArgumentException("Error: You must specify a \"form-data name\" for the HttpPutFile action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     URL                  = " + url);
      UFM.logger.info("     Source FileName      = " + (srcFilename == null ? "":srcFilename));
      UFM.logger.info("     form-data name       = " + formDataName);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      if (srcFilename.indexOf(File.separator) != -1 )
      {
         int x = srcFilename.lastIndexOf(File.separator);

         String dir   = srcFilename.substring(0, x);
         String fname = srcFilename.substring(x+1);

         file = "<"+CWConstants.FILE_ELEMENT+" "+CWConstants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+CWConstants.FILE_ELEMENT+">";
      }
      else
         file = "<"+CWConstants.FILE_ELEMENT+">"+srcFilename+"</"+CWConstants.FILE_ELEMENT+">";
      
      al.add("<"+CWConstants.HTTP_PUT_FILE_ELEMENT+" "+CWConstants.URL_ATTRIBUTE+"=\""+url+"\" "+CWConstants.FORM_DATA_NAME_ATTRIBUTE+"=\""+formDataName+" >"+LINE_SEPARATOR);
      
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+CWConstants.HTTP_PUT_FILE_ELEMENT+">"+LINE_SEPARATOR);

      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      if (srcFilename == null)
         s = CWConstants.HTTP_PUT_FILE_ELEMENT+", "+labelName+", "+CWConstants.HTTP_PUT_FILE_ELEMENT+", "+CWConstants.URL_ATTRIBUTE+"="+url+", "+CWConstants.FORM_DATA_NAME_ATTRIBUTE+"="+formDataName+LINE_SEPARATOR;
      else
         s = CWConstants.HTTP_PUT_FILE_ELEMENT+", "+labelName+", "+CWConstants.HTTP_PUT_FILE_ELEMENT+", "+CWConstants.URL_ATTRIBUTE+"="+url+", "+CWConstants.FORM_DATA_NAME_ATTRIBUTE+"="+formDataName+", srcFilename="+srcFilename+LINE_SEPARATOR;

      return s;
   }
}
