package com.capitalware.ufm.action.objects;

import java.lang.reflect.Field;
import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the If action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class IfObject extends UFMObject
{
   public String              ifLabelName = "default";
   public String              ifActionName = null;
   public String              ifFieldName = null;
   public String              operator = null;
   public String              value = null;
   public ArrayList<UFMObject> actionAL = null;
   public ElseObject          eo = null;
   
   /**
    * The constructor
    */
   public IfObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      String objectName = "com.capitalware.ufm.action.objects."+ifActionName+"Object";
      
      if ( (ifLabelName == null) || ("".equals(ifLabelName)) )
         throw new IllegalArgumentException("Error: The labelname attribute for the 'If' action cannot be blank.");

      if ( (ifActionName == null) || ("".equals(ifActionName)) )
         throw new IllegalArgumentException("Error: The actionname attribute for the 'If' action cannot be blank.");

      if ( (ifFieldName == null) || ("".equals(ifFieldName)) )
         throw new IllegalArgumentException("Error: The fieldname attribute for the 'If' action cannot be blank.");
      
      try
      {
         UFMObject fmo = (UFMObject)Class.forName(objectName).newInstance();
         
         if (!isFieldFromClass(fmo, ifFieldName))
            throw new IllegalArgumentException("Error: The fieldname attribute called '"+ifFieldName+"' does not exist for class: "+ifActionName+"Object");
      }
      catch (InstantiationException e)
      {
         UFM.logger.fatal("InstantiationException: " + e.getLocalizedMessage());
         throw new IllegalArgumentException("Error: Cannot instantiate the class called: "+ifActionName+"Object");
      }
      catch (IllegalAccessException e)
      {
         UFM.logger.fatal("IllegalAccessException: " + e.getLocalizedMessage());
         throw new IllegalArgumentException("Error: The fieldname attribute for the 'If' had IllegalAccessException error.");
      }
      catch (ClassNotFoundException e)
      {
         UFM.logger.fatal("ClassNotFoundException: " + e.getLocalizedMessage());
         throw new IllegalArgumentException("Error: Cannot find the class called: "+ifActionName+"Object");
      }
      
      if ( (operator == null) || ("".equals(operator)) )
         throw new IllegalArgumentException("Error: The operator attribute for the 'If' action cannot be blank.");

      if ( !("EQ".equals(operator)) && !("NE".equals(operator)) && 
           !("LT".equals(operator)) && !("LE".equals(operator)) && 
           !("GT".equals(operator)) && !("GE".equals(operator)) )
         throw new IllegalArgumentException("Error: The operator attribute for the 'If' action must contain one of the following values: EQ, NE, LT, LE, GT or GE.  It currently contains: "+operator);
      
      if ( (value == null) || ("".equals(value)) )
         throw new IllegalArgumentException("Error: The value attribute for the 'If' action cannot be blank.");
   }

   /**
    * 
    * @param fmo
    * @param fieldName
    * @return
    */
   private boolean isFieldFromClass(UFMObject fmo, String fieldName)
   {
      boolean flag = false;
      Class c = fmo.getClass();
      
      try
      {
         Field f = c.getField(fieldName);
         flag = true;
      }
      catch (SecurityException e)
      {
         UFM.logger.fatal("SecurityException: " + e.getLocalizedMessage());
      }
      catch (NoSuchFieldException e)
      {
         UFM.logger.fatal("NoSuchFieldException: " + e.getLocalizedMessage());
      }
      catch (IllegalArgumentException e)
      {
         UFM.logger.fatal("IllegalArgumentException: " + e.getLocalizedMessage());
      }
      
      return flag;
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     labelname            = " + ifLabelName);
      UFM.logger.info("     actionname           = " + ifActionName);
      UFM.logger.info("     fieldname            = " + ifFieldName);
      UFM.logger.info("     operator             = " + operator);
      UFM.logger.info("     value                = " + value);
      
      if (actionAL != null)
      {
         UFM.logger.info("     If Actions to be processed:");
         for (int i=0; i < actionAL.size(); i++)
         {
            UFMObject fmo = (UFMObject)actionAL.get(i);
            UFM.logger.info("       Action ["+(i+1)+"]         = " + fmo.actionName);
         }
      }
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      al.add("<"+CWConstants.IF_ELEMENT+" "+CWConstants.LABEL_NAME_ATTRIBUTE+"=\""+ifLabelName+"\" "+CWConstants.ACTION_NAME_ATTRIBUTE+"=\""+ifActionName+"\" fieldname=\""+ifFieldName+"\" "+CWConstants.OPERATOR_ATTRIBUTE+"=\""+operator+"\" "+CWConstants.VALUE_ATTRIBUTE+"=\""+value+"\">"+LINE_SEPARATOR);

      /*
       * Add info from actions
       */
      if (actionAL != null)
      {
         for (int i=0; i < actionAL.size(); i++)
         {
            UFMObject fmo = (UFMObject)actionAL.get(i);
            ArrayList<String> actionAL = fmo.toStringArray();
            for (int j=0; j < actionAL.size(); j++)
            {
               al.add("  "+actionAL.get(j));
            }
         }
      }
      
      al.add("</"+CWConstants.IF_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      s = CWConstants.IF_ELEMENT+", "+labelName+", "+CWConstants.IF_ELEMENT+", "+CWConstants.ACTION_NAME_ATTRIBUTE+"="+ifActionName+", "+CWConstants.FIELD_NAME_ATTRIBUTE+"="+ifFieldName+", "+CWConstants.OPERATOR_ATTRIBUTE+"="+operator+", "+CWConstants.VALUE_ATTRIBUTE+"="+value+LINE_SEPARATOR;

      return s;
   }
}
