package com.capitalware.ufm.action.objects;


import java.io.File;
import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the RemoveItems action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class RemoveItemsObject extends UFMFileObject
{
   public String     srcFilename = null;
   public String     itemFilename = null;
   public String     toFile = null;
   public String     toDir = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public RemoveItemsObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (srcFilename != null)
         srcFilename   = Tokens.replace(srcFilename, paClass.actionProperties);
      if (toFile != null)
         toFile = Tokens.replace(toFile, paClass.actionProperties);
      if (toDir != null)
         toDir  = Tokens.replace(toDir, paClass.actionProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      checkAndCreateDirectory(createDir, toDir);
      
      if (srcFilename == null)
         throw new IllegalArgumentException("Error: You must specify a filename for the RemoveItems action.");
      
      if (itemFilename == null)
         throw new IllegalArgumentException("Error: You must specify a ItemFile for the RemoveItems action.");

      if (toDir == null)
         throw new IllegalArgumentException("Error: You must specify a TargetDirectory for the RemoveItems action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     Source File          = " + srcFilename);
      UFM.logger.info("     Item File            = " + itemFilename);
      UFM.logger.info("     Target Directory     = " + toDir);
      UFM.logger.info("     Target File          = " + (toFile == null ? "":toFile));
      UFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      al.add("<"+CWConstants.REMOVE_ITEMS_ELEMENT+">"+LINE_SEPARATOR);

      if (srcFilename.indexOf(File.separator) != -1 )
      {
         int x = srcFilename.lastIndexOf(File.separator);

         String dir   = srcFilename.substring(0, x);
         String fname = srcFilename.substring(x+1);

         file = "<"+CWConstants.FILE_ELEMENT+" "+CWConstants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+CWConstants.FILE_ELEMENT+">";
      }
      else
         file = "<"+CWConstants.FILE_ELEMENT+">"+srcFilename+"</"+CWConstants.FILE_ELEMENT+">";

      if (itemFilename.indexOf(File.separator) != -1 )
      {
         int x = itemFilename.lastIndexOf(File.separator);

         String dir   = itemFilename.substring(0, x);
         String fname = itemFilename.substring(x+1);

         file = "<"+CWConstants.ITEM_FILE_ELEMENT+" "+CWConstants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+CWConstants.ITEM_FILE_ELEMENT+">";
      }
      else
         file = "<"+CWConstants.ITEM_FILE_ELEMENT+">"+itemFilename+"</"+CWConstants.ITEM_FILE_ELEMENT+">";

      if (toFile == null)
         al.add("<"+CWConstants.REMOVE_ITEMS_ELEMENT+" "+CWConstants.TO_DIR_ATTRIBUTE+"=\""+toDir+"\">"+LINE_SEPARATOR);
      else
         al.add("<"+CWConstants.REMOVE_ITEMS_ELEMENT+" "+CWConstants.TO_DIR_ATTRIBUTE+"=\""+toDir+"\" "+CWConstants.TO_FILE_ATTRIBUTE+"=\""+toFile+">"+LINE_SEPARATOR);
      
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+CWConstants.REMOVE_ITEMS_ELEMENT+">"+LINE_SEPARATOR);

      return al;
   }
   
   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      if (toFile == null)
         s = CWConstants.REMOVE_ITEMS_ELEMENT+", "+labelName+", "+CWConstants.REMOVE_ITEMS_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", srcFilename="+srcFilename+", itemFilename="+itemFilename+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+LINE_SEPARATOR;
      else
         s = CWConstants.REMOVE_ITEMS_ELEMENT+", "+labelName+", "+CWConstants.REMOVE_ITEMS_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", srcFilename="+srcFilename+", itemFilename="+itemFilename+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+", "+CWConstants.TO_FILE_ATTRIBUTE+"="+toFile+LINE_SEPARATOR;

      return s;
   }
}
