package com.capitalware.ufm.actions;

import java.io.File;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.RemoveDirObject;
import com.capitalware.ufm.handlers.IO;

/**
 * This class will handle the RemoveDir action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class RemoveDirAction extends UFMAction
{
   private RemoveDirObject   rdo;

   /**
    * The constructor
    * @param rdo
    */
   public RemoveDirAction(RemoveDirObject rdo)
   {
      super(rdo.actionName);
      this.rdo = rdo;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      rdo.printValues();

      if ((new File(rdo.targetDir)).exists())
      {
         if (rdo.removeAll)
         {
            if (IO.deleteDir(new File(rdo.targetDir)))
            {
               UFM.logger.info("Successfully deleted directory: " + rdo.targetDir);
            }
            else
            {
               UFM.logger.fatal("Cannot deleted directory: " + rdo.targetDir);
               UFM.globalErrorText = "Cannot deleted directory: " + rdo.targetDir;
               
               if (!rdo.onErrorFail)
                  UFM.handleOnError(rdo.paClass.actionProperties, null);
               
               exitCode = 8;
            }
         }
         else
         {
            if ((new File(rdo.targetDir)).delete()) 
            {
               UFM.logger.info("Successfully deleted directory: " + rdo.targetDir);
            }
            else
            {
               UFM.logger.fatal("Cannot deleted directory: " + rdo.targetDir);
               UFM.globalErrorText = "Cannot deleted directory: " + rdo.targetDir;
               
               if (!rdo.onErrorFail)
                  UFM.handleOnError(rdo.paClass.actionProperties, null);
               
               exitCode = 8;
            }
         }
      }
      else
      {
         UFM.logger.warn("Directory does not exist: " + rdo.targetDir);
      }
      
      if (!rdo.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
