package com.capitalware.ufm.actions;

import java.io.File;
import java.io.IOException;
import java.util.List;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.SortObject;
import com.capitalware.ufm.handlers.ExternalSort;
import com.capitalware.ufm.handlers.ExternalSortComparator;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.handlers.Tokens;

/**
 * This class will handle the sort action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class SortAction extends UFMAction
{
   private SortObject   so;

   /**
    * The constructor
    * @param sfo
    */
   public SortAction(SortObject so)
   {
      super(so.actionName);
      this.so = so;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      String toPathAndFilename;
      so.printValues();

      toPathAndFilename = IO.apendFileToPath(so.toDir, so.toFile);
      toPathAndFilename = Tokens.replace(so.actionName, toPathAndFilename, IO.getFileName(so.srcFilename), 1, so.paClass.actionProperties);
      
      try
      {
         ExternalSortComparator esc = new ExternalSortComparator(so);
         List<File> l = ExternalSort.sortInBatch(new File(so.srcFilename), esc);
         ExternalSort.mergeSortedFiles(l, new File(toPathAndFilename), esc);
         
         so.fileCount++;

         UFM.logger.info("Successfully sorted '" + so.srcFilename + "' to file '" + toPathAndFilename + "'");
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      finally
      {
         if (!so.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
