package com.capitalware.ufm.actions;

import java.io.File;
import java.io.IOException;
import java.util.List;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.SortUniqueObject;
import com.capitalware.ufm.handlers.ExternalSort;
import com.capitalware.ufm.handlers.ExternalSortComparator;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the SortUnique action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class SortUniqueAction extends UFMAction
{
   private SortUniqueObject   suo;

   /**
    * The constructor
    * @param sfo
    */
   public SortUniqueAction(SortUniqueObject suo)
   {
      super(suo.actionName);
      this.suo = suo;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      String toPathAndFilename;
      File tempFile;
      suo.printValues();

      toPathAndFilename = IO.apendFileToPath(suo.toDir, suo.toFile);
      toPathAndFilename = Tokens.replace(suo.actionName, toPathAndFilename, IO.getFileName(suo.srcFilename), 1, suo.paClass.actionProperties);
      
      try
      {
         tempFile = File.createTempFile(com.capitalware.ufm.UFM.WHO_AM_I+"_"+suo.actionName+"_", ".tmp");
         
         // Delete temp file when program exits.
         tempFile.deleteOnExit();      


         ExternalSortComparator esc = new ExternalSortComparator(suo);
         List<File> l = ExternalSort.sortInBatch(new File(suo.srcFilename), esc) ;
         ExternalSort.mergeSortedFiles(l, tempFile, esc);
         
         int dupCount = IO.unique(tempFile.getAbsolutePath(), toPathAndFilename);
         
         UFM.logger.info("Successfully sorted then removed "+dupCount+" duplicate lines from file: "+suo.srcFilename+ " to " + toPathAndFilename);
         
         suo.fileCount++;
         
         if (!(tempFile.delete()))
            UFM.logger.fatal("Error: Cannot delete temporary file: "+tempFile.getAbsolutePath());
      }
      catch (UFMException e)
      {
         UFM.logger.fatal("UFMException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      finally
      {
         if (!suo.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
