package com.capitalware.ufm.actions;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.TouchObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the touch action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class TouchAction extends UFMAction
{
   private TouchObject   to;

   /**
    * The constructor
    * @param sfo
    */
   public TouchAction(TouchObject to)
   {
      super(to.actionName);
      this.to = to;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      to.printValues();

      try
      {
         to.filenames = IO.buildStringArrayOfFiles(to.filenames);
         
         for (int i=0; (i < to.filenames.length) && (exitCode == 0); i++)
         {
            try
            {
               IO.touchFile(to.filenames[i]);
               to.fileCount++;
            }
            catch (UFMException e)
            {
               UFM.logger.fatal("UFMException: "+e.getLocalizedMessage());
               if (e.getCause() != null)
                  UFM.logger.fatal(e.getCause().toString());;
               if (to.onErrorFail)
                  exitCode = 8;
            }
         }
      }
      catch (UFMException e)
      {
         UFM.logger.fatal("UFMException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      finally
      {
         if (!to.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
