package com.capitalware.ufm.actions;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.UniqueObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the Unique action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class UniqueAction extends UFMAction
{
   private UniqueObject   uo;

   /**
    * The constructor
    * @param sfo
    */
   public UniqueAction(UniqueObject uo)
   {
      super(uo.actionName);
      this.uo = uo;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      String toPathAndFilename;
      uo.printValues();

      toPathAndFilename = IO.apendFileToPath(uo.toDir, uo.toFile);
      toPathAndFilename = Tokens.replace(uo.actionName, toPathAndFilename, IO.getFileName(uo.srcFilename), 1, uo.paClass.actionProperties);
      
      try
      {
         int dupCount = IO.unique(uo.srcFilename, toPathAndFilename);
         
         UFM.logger.info("Successfully removed "+dupCount+" duplicate lines from file: "+uo.srcFilename+ " to " + toPathAndFilename);
         
         uo.fileCount++;
      }
      catch (UFMException e)
      {
         UFM.logger.fatal("UFMException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      finally
      {
         if (!uo.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
