package com.capitalware.ufm.actions;

import javax.swing.Timer;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.WatchObject;
import com.capitalware.ufm.handlers.InternalMessageQueue;
import com.capitalware.ufm.handlers.ShutdownThread;
import com.capitalware.ufm.watch.TimerListener;

/**
 * This class will handle watch action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class WatchAction extends UFMAction
{
   private WatchObject     wo;
   private Timer           timer;
   private TimerListener   timerListener;
   private InternalMessageQueue    iq = null;

   /**
    * The constructor
    * @param wo
    */
   public WatchAction(WatchObject wo, InternalMessageQueue iq)
   {
      super(wo.actionName);
      this.wo = wo;
      this.iq = iq;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      Thread currentThread = null;

      try
      {
         wo.printValues();

         currentThread = Thread.currentThread();
         Runtime.getRuntime().addShutdownHook(new ShutdownThread("WatchAction", currentThread));
         UFM.addThread(currentThread);

         timerListener = new TimerListener(wo.watches, wo.paClass.actionProperties, iq);
         timer = new Timer(wo.pollInterval, timerListener);
         timer.start();

         // do your work until the thread is interrupted
         try
         {
            while (!currentThread.isInterrupted())
            {
               Thread.sleep(1000);
            }
         }
         catch (InterruptedException e)
         {
            UFM.logger.info("WatchAction wait loop was interrupted.");
         }

         UFM.logger.info("WatchAction: Beginning cleanup to exit.");

         timer.stop();

         for (int i=0; (i < 3) && timerListener.isWorking();i++)
         {
            if (timerListener.isWorking())
               try {Thread.sleep(1000);} catch (InterruptedException e){}
         }
      }
      catch (Exception e)
      {
         UFM.logger.fatal("Exception: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      finally
      {
         if (currentThread != null)
         {
            // Put a slight delay so that the child thread can get to the wait method.
            try {Thread.sleep(75);} catch (InterruptedException e){}
            
            UFM.logger.info("WatchAction: Sending notification.");
            // notify controller thread that we have finished
            synchronized (currentThread)
            {
               currentThread.notifyAll();
               UFM.logger.info("WatchAction: Sent notification.");
            }
         }
      }

      UFM.logger.info("WatchAction: All done - time to exit.");

      if (!wo.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
