package com.capitalware.ufm.handlers;

import java.io.*;
import java.util.*;

/**
 * This class will handle recursing into sub-directories.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class DirectoryRecurser implements Enumeration<File>
{
   private Vector<File> fileVector = new Vector<File>();
   private Enumeration<File> elements;

   /**
    * The constructor
    * @param directory
    * @throws IOException
    */
   public DirectoryRecurser(File directory) throws IOException
   {
      getFiles(directory);
      elements = fileVector.elements();
   }

   /**
    * Get a list of files
    * @param dir
    * @throws IOException
    */
   private void getFiles(File dir) throws IOException
   {
      if (dir.isDirectory())
      {
         fileVector.addElement(dir);
         File[] fileList = dir.listFiles();
         if (fileList != null)
         {
            for (int i = 0; i < fileList.length; i++)
            {
               if (fileList[i].isDirectory())
               {
                  getFiles(fileList[i]);
               }
               else
               {
                  fileVector.addElement(fileList[i]);
               }
            }
         }
      }
      else
      {
         throw new IOException("Not a directory: " + dir);
      }
   }

   /**
    * Are there more elements?
    *
    * @return True / false
    */
   public boolean hasMoreElements()
   {
      return elements.hasMoreElements();
   }

   /**
    * Retrieve the next element
    *
    * @return Object
    */
   public File nextElement()
   {
      return elements.nextElement();
   }
}
