package com.capitalware.ufm.handlers;

import com.capitalware.ufm.UFM;

/**
 * ShutdownThread implements a new virtual-machine shutdown hook. 
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class ShutdownThread extends Thread
{
   private Thread workerThread = null;
   private String callerName = "";

   /**
    * The constructor
    * @param callerName
    * @param workerThread
    */
   public ShutdownThread(String callerName, Thread workerThread)
   {
      this.callerName = callerName;
      this.workerThread = workerThread;
   }

   /**
    * Do the work.
    */
   public void run()
   {
      UFM.logger.info(callerName+": Shutdown requested.");

      if (workerThread != null)
      {
         // request worker thread to finish
         workerThread.interrupt();

         // wait for the worker thread to finish
         try
         {
            synchronized (workerThread)
            {
               workerThread.wait();
            }
         }
         catch (InterruptedException e)
         {}
      }

      UFM.logger.info(callerName+": Shutting down.");
   }
}
