package com.capitalware.ufm.mq.objects;

import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.UFMFileMQObject;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the Status action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class StatusObject extends UFMFileMQObject
{
   public int        timeToLive = CWConstants.TIME_TO_LIVE_DEFAULT; 
   
   /**
    * The constructor
    */
   public StatusObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (timeToLive < 1)
         timeToLive = CWConstants.TIME_TO_LIVE_DEFAULT;
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     TimeToLive           = " + timeToLive);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      al.add("<"+CWConstants.STATUS_ELEMENT+ " "+CWConstants.TIME_TO_LIVE_ATTRIBUTE+"="+timeToLive+">"+LINE_SEPARATOR);

      /*
       * MQ info
       */
      ArrayList<String> mqt = createMQTag();
      for (int i=0; i < mqt.size(); i++)
         al.add(mqt.get(i));
      
      al.add("</"+CWConstants.STATUS_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      s = CWConstants.STATUS_ELEMENT+", "+labelName+", "+event+", "+CWConstants.TIME_TO_LIVE_ATTRIBUTE+"="+timeToLive+LINE_SEPARATOR;

      return s;
   }
}
