package com.capitalware.ufm.xml;

import org.jdom.*;

import com.capitalware.ufm.objects.CWConstants;

import java.io.*;

/**
 * This class is an abstract class for XML parsing classes.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public abstract class UFMXmlAbstract
{

   /**
    * The constructor
    *
    * @param logger
    */
   public UFMXmlAbstract()
   {
      super();
   }

   /**
    * Retrieve the value for the "On Error Fail" attribute.
    * @param element
    * @return flag boolean
    */
   protected boolean getOnErrorFailAttribute(Element element, boolean defaultOnErrorFail)
   {
      boolean onErrorFail = true;
      char o = ' ';

      if (element.getAttribute(CWConstants.ON_ERROR_FAIL_ATTRIBUTE) != null)
         o = element.getAttribute(CWConstants.ON_ERROR_FAIL_ATTRIBUTE).getValue().toUpperCase().charAt(0);

      if (o ==  ' ')
         onErrorFail = defaultOnErrorFail;
      else if (o == 'Y')
         onErrorFail = true;
      else if (o == 'N')
         onErrorFail = false;

      return onErrorFail;
   }

   /**
    * Read XML file and set parameters
    *
    * @param xmlFilename
    *           The name of xml file
    * @throws JDOMException, IOException
    */
   public abstract void readXMLFile(String xmlFilename) throws JDOMException, IOException;
}
